Learn R Programming

thankr (version 1.0.0.9000)

gh_starred: Check if you starred packages on Github

Description

Starring a package on Github is a form of appreciation for the project. With this function you can quickly check if you starred all your favorite packages.

Usage

gh_starred(packages, console_output = TRUE,
  api_url = "https://api.github.com",
  user_agent = "https://github.com/dirkschumacher/thankr")

Arguments

packages

a non empty character vector of package names.

console_output

Optional. TRUE if the result should be written to the console

api_url

Optional. The GitHub API url.

user_agent

Optional. The user-agent for all the API requests. Change it if this function is part of something bigger.

Value

Always returns a data.frame with three columns "username", "repository" and "starred". If console_output is TRUE, then the return value is invisible.

Details

Still under development. Api and names can change.

The function assumes that you have set an environment variable (either GITHUB_PAT or GITHUB_TOKEN) with a Github Access Token.

When using this function together with shoulders please note that once run for the first time additional packages are attached to your session.

Also take a look at the API documentation <https://developer.github.com/v3/> of Github and their terms of use before using this function.

References

Inspired by <https://github.com/musically-ut/appreciate>